Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
Functions ¶
func MustBuildJSON ¶
func MustBuildJSON[T any](data json.RawMessage) *T
MustBuildJSON factory, use it if the error is not worth handling.
Types ¶
type RawMessageSequenceMap ¶
type RawMessageSequenceMap struct {
// contains filtered or unexported fields
}
RawMessageSequenceMap provides deterministic, per-key sequences of json.RawMessage values. It is useful for testing scenarios where each key should return a specific sequence of values on consecutive calls.
func NewRawMessageSequenceMap ¶
func NewRawMessageSequenceMap(input map[string][]json.RawMessage) *RawMessageSequenceMap
NewRawMessageSequenceMap initialises and returns a new instance of JSONSequence.
func (*RawMessageSequenceMap) Next ¶
func (s *RawMessageSequenceMap) Next(key string) json.RawMessage
Next returns the next json.RawMessage for the given key in the predefined sequence. If the key is unknown or has an empty sequence, it returns nil. If the sequence is exhausted, the last value is returned repeatedly.
type Serialiser ¶ added in v0.0.2
type Serialiser struct{}
Serialiser is a serialiser service.
func NewSerialiser ¶ added in v0.0.2
func NewSerialiser() *Serialiser
NewSerialiser a group specific factory.
Click to show internal directories.
Click to hide internal directories.