Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ProviderFunc ¶
ProviderFunc provides the current time. It can be replaced in tests to control time behaviour.
func (ProviderFunc) Now ¶
func (t ProviderFunc) Now() time.Time
Now returns the current time using the provider. If the provider is nil, time.Now is used.
func (ProviderFunc) Unix ¶ added in v0.0.5
func (t ProviderFunc) Unix() int64
Unix returns t as a Unix time, the number of seconds elapsed since January 1, 1970 UTC. The result does not depend on the location associated with t.
Click to show internal directories.
Click to hide internal directories.